@@ -7,11 +7,15 @@ export const getFormatsDisplay = (formats: ReportFormat[]) => {
     formats
       .map((format) => {
         switch (format) {
-          case 'csv':
-          case 'pdf':
+          case ReportFormat.CSV:
+          case ReportFormat.PDF:
             return format.toUpperCase();
-          case 'image':
+          case ReportFormat.Image:
             return 'embedded image';
+          case ReportFormat.PDFTablesAppendix:
+            return 'PDF tables appendix';
+          case ReportFormat.PDFTables:
+            return 'PDF tables';
         }
       })
       .join(', ')
